package com.xxfc.platform.summit.interceptor;


import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import cn.hutool.core.codec.Base64;
import com.alibaba.fastjson.JSON;
import com.github.wxiaoqi.security.common.util.UserAgentUtil;
import com.xxfc.platform.summit.service.WeixinService;
import com.xxfc.platform.summit.vo.UserInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;
import com.alibaba.fastjson.JSONObject;


/**
 * 微信登陆拦截器
 * 
 * @author
 *
 */
@Slf4j
public class WeChatH5LoginInterceoptor extends HandlerInterceptorAdapter {

	/**
	 * 微信公众号自动登陆令牌的url参数名
	 */
	public static final String WECHAT_AUTOLOGIN_CALLBACKURL_KEY = "wechat_autologin_callback_accesstoken";

	public static final String frontSessionKey = "frontWeixKey";

	@Value("${wx.url}")
	private String  url;

	@Autowired
	WeixinService weixinService;


	@Override
	public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {

		String curr_domain = request.getServerName();
		HttpSession session = request.getSession();
		log.info("curr_domain:" + curr_domain);
		log.info("address:" + request.getRequestURL().toString());
		log.info("params:" + request.getQueryString());

		boolean isWx = UserAgentUtil.isWexinBrowser(request);
		if (isWx) {
			String frontSessionValue1 = (String) session.getAttribute(frontSessionKey);
			if (StringUtils.isNotBlank(frontSessionValue1)) {
				String frontSessionValue =  new String(Base64.decode(frontSessionValue1), "utf-8");
				 return  true;
			}
			/*String curr_url = request.getRequestURL().toString()
					+ (StringUtils.isBlank(request.getQueryString()) ? "" : "?" + request.getQueryString());*/
			String curr_url="https://dev.dfangche.com/api/summit/activity/app/unauth/index";
			String encrypt_curr_url = Base64.encode(curr_url);
			String code = request.getParameter("code");
			// 没有code, 则进行网页授权获取code
			log.info("curr_url=====" + curr_url + "-----code=" + code);
			if (StringUtils.isBlank(code)) {
				String redirec_url=curr_url+"?" + WECHAT_AUTOLOGIN_CALLBACKURL_KEY+ "=" + encrypt_curr_url;
				String oauth_api=weixinService.getAuthorize(curr_url);
				log.info("curr_url=====" + curr_url);
				response.sendRedirect("https://www.baidu.com");
				return false;
			}
			// 有code, 换取openid
			String openid = null;
			String access_token = null;
			try {
				log.info("调用微信网页授权接口code=" + code);
				JSONObject access_token_json=weixinService.getAccessToken(code);
				if (access_token_json == null || StringUtils.isNotBlank(access_token_json.getString("errcode"))) {
					log.info("err: " + JSON.toJSONString(access_token_json));
					log.info("调用微信网页授权接口失败, appid或者appsecret不正确");
					return false;
				}
				openid = access_token_json.getString("openid").trim();
				access_token = access_token_json.getString("access_token");
				UserInfo userInfo=new UserInfo();
				userInfo.setOpenId(openid);
				log.error("UserInfo===" + JSONObject.toJSONString(userInfo));
				String encode = Base64.encode(JSONObject.toJSONString(userInfo));
				session.removeAttribute(frontSessionKey);
				session.setAttribute(frontSessionKey, encode);
			} catch (Exception e) {
				log.info("【" + curr_url + "】获取access_token失败");
				return false;
			}
			// 重定向到原来地址后进行自动登陆
			String encrypt_callbackurl = request.getParameter(WECHAT_AUTOLOGIN_CALLBACKURL_KEY);
			String decrypt_callbackurl =Base64.encode(encrypt_callbackurl.getBytes("utf-8"));
			log.error("decrypt_callbackurl===" + decrypt_callbackurl);
			response.sendRedirect(decrypt_callbackurl);
			return false;

		}
		return  true;
	}


}
